/*
 *	OLDE Display (SH1107) 表示ライブラリ API定義
 */

IMPORT ER oled_init(ID dd_i2c);				// OLED 初期化
IMPORT ER oled_onoff(ID dd_i2c, UINT onoff);		// OLED オン・オフ
IMPORT ER oled_fill_screen(ID dd_i2c, UB val);		// OLED全画像塗りつぶし
IMPORT ER oled_copy_screen(ID dd_i2c, UB *buf);		// OLED全画像コピー
IMPORT ER oled_copy_block(ID dd_i2c, UINT sx, UINT sy, UINT w, UINT h, UB *buf);	 // OLDE画像転送

/* 文字表示 */
IMPORT ER oled_fnt8_printc(ID dd_i2c, UINT x, UINT y, UB ch);		// 8ピクセル文字
IMPORT ER oled_fnt8_prints(ID dd_i2c, UINT col, UINT line, UB *str);	// 8ピクセル文字列
IMPORT ER oled_fnt24_printc(ID dd_i2c, UINT col, UINT line, UB ch);	// 24ピクセル文字
IMPORT ER oled_fnt24_prints(ID dd_i2c, UINT col, UINT line, UB *str);	// 24ピクセル文字列
